summaryrefslogtreecommitdiffstats
path: root/uitest/src/com/vaadin/tests/themes/LegacyComponentThemeChangeTest.java
diff options
context:
space:
mode:
Diffstat (limited to 'uitest/src/com/vaadin/tests/themes/LegacyComponentThemeChangeTest.java')
-rw-r--r--uitest/src/com/vaadin/tests/themes/LegacyComponentThemeChangeTest.java5
1 files changed, 3 insertions, 2 deletions
diff --git a/uitest/src/com/vaadin/tests/themes/LegacyComponentThemeChangeTest.java b/uitest/src/com/vaadin/tests/themes/LegacyComponentThemeChangeTest.java
index 8062fdbf39..1814aa99df 100644
--- a/uitest/src/com/vaadin/tests/themes/LegacyComponentThemeChangeTest.java
+++ b/uitest/src/com/vaadin/tests/themes/LegacyComponentThemeChangeTest.java
@@ -72,8 +72,9 @@ public class LegacyComponentThemeChangeTest extends MultiBrowserTest {
}
private void assertEmbeddedTheme(String theme) {
- if (BrowserUtil.isIE8(getDesiredCapabilities())) {
- // IE8 won't initialize the dummy flash properly
+ if (BrowserUtil.isIE8(getDesiredCapabilities())
+ || BrowserUtil.isChrome(getDesiredCapabilities())) {
+ // IE8 and Chrome 47 won't initialize the dummy flash properly
return;
}
EmbeddedElement e = $(EmbeddedElement.class).first();